@@ -25,11 +25,6 @@ class GetApiDestinationRequest(RpcRequest):
 		RpcRequest.__init__(self, 'eventbridge', '2020-04-01', 'GetApiDestination')
 		self.set_method('POST')
 
-	def get_ClientToken(self): # String
-		return self.get_query_params().get('ClientToken')
-
-	def set_ClientToken(self, ClientToken):  # String
-		self.add_query_param('ClientToken', ClientToken)
 	def get_ApiDestinationName(self): # String
 		return self.get_query_params().get('ApiDestinationName')
 
